mouse_diff

Function mouse_diff 

pub fn mouse_diff() -> Vec2
Returns the change in mouse coordinates that occurred during the last step.

This is useful when implementing first person controls with a captured mouse.