pub fn action_pressed_os(action: Action) -> boolExpand description
Returns true when the action’s bound button goes from “not pressed” to “pressed”. Otherwise returns false.
For keyboard keys, will repeat key presses while held down according to the OS’s key repeat configuration. This is suitable for UI.
Returns false if the action is not bound to any button.