pub fn key_held_logical(check_key: Key<&str>) -> bool
Returns true while the specified keyboard key remains “pressed”. Otherwise returns false.
Uses logical keypresses, so for example W is changed between a US and french keyboard.